package Paws::SimpleWorkflow::StartTimerDecisionAttributes;
  use Moose;
  has control => (is => 'ro', isa => 'Str');
  has startToFireTimeout => (is => 'ro', isa => 'Str', required => 1);
  has timerId => (is => 'ro', isa => 'Str', required => 1);
1;
